@@ -1,12 +1,14 @@
-/*********************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 
 import axios, { AxiosInstance } from 'axios'
 import * as fs from 'fs-extra'
@@ -15,6 +17,7 @@ import * as path from 'path'
 import * as querystring from 'querystring'
 
 import { ACCESS_TOKEN_KEY } from '../common-flags'
+import { findWorkingNamespace } from '../util'
 
 import { CheHelper } from './che'
 import { CheApiClient } from './che-api-client'
@@ -62,15 +65,15 @@ export interface PasswordLoginRecord {
 }
 
 export function isRefreshTokenLoginData(loginData: LoginRecord): loginData is RefreshTokenLoginRecord {
-  return !!(loginData as RefreshTokenLoginRecord).refreshToken
+  return Boolean((loginData as RefreshTokenLoginRecord).refreshToken)
 }
 
 export function isOcUserTokenLoginData(loginData: LoginRecord): loginData is OcUserTokenLoginRecord {
-  return !!(loginData as OcUserTokenLoginRecord).subjectToken
+  return Boolean((loginData as OcUserTokenLoginRecord).subjectToken)
 }
 
 export function isPasswordLoginData(loginData: LoginRecord): loginData is PasswordLoginRecord {
-  return !!(loginData as PasswordLoginRecord).password
+  return Boolean((loginData as PasswordLoginRecord).password)
 }
 
 // Response structure from <che-host>/api/keycloak/settings
@@ -114,10 +117,13 @@ let loginContext: CheServerLoginManager | undefined
  */
 export class CheServerLoginManager {
   private loginData: CheServerLoginConfig
+
   private apiUrl: string
+
   private username: string
 
   private readonly dataFilePath: string
+
   private readonly axios: AxiosInstance
 
   private constructor(dataFilePath: string) {
@@ -134,7 +140,7 @@ export class CheServerLoginManager {
     // Make axios ignore untrusted certificate error for self-signed certificate case.
     const httpsAgent = new https.Agent({ rejectUnauthorized: false })
     this.axios = axios.create({
-      httpsAgent
+      httpsAgent,
     })
   }
 
@@ -165,9 +171,9 @@ export class CheServerLoginManager {
   public hasLoginFor(apiUrl: string, username?: string): boolean {
     apiUrl = CheApiClient.normalizeCheApiEndpointUrl(apiUrl)
     if (username) {
-      return !!this.getLoginRecord(apiUrl, username)
+      return Boolean(this.getLoginRecord(apiUrl, username))
     } else {
-      return !!this.loginData.logins![apiUrl]
+      return Boolean(this.loginData.logins![apiUrl])
     }
   }
 
@@ -184,7 +190,7 @@ export class CheServerLoginManager {
 
     const allLogins = new Map<string, string[]>()
     for (const [apiUrl, serverLogins] of Object.entries(this.loginData.logins!)) {
-      allLogins.set(apiUrl, Array.from(Object.keys(serverLogins)))
+      allLogins.set(apiUrl, [...Object.keys(serverLogins)])
     }
     return allLogins
   }
@@ -211,7 +217,7 @@ export class CheServerLoginManager {
     }
     const refreshTokenLoginRecord: RefreshTokenLoginRecord = {
       refreshToken: keycloakAuthData.refresh_token,
-      expires: now + refreshTokenExpiresIn
+      expires: now + refreshTokenExpiresIn,
     }
 
     const username = isPasswordLoginData(loginRecord) ? loginRecord.username :
@@ -448,7 +454,7 @@ export class CheServerLoginManager {
       password,
     }
     const headers = {
-      'Content-Type': 'application/x-www-form-urlencoded'
+      'Content-Type': 'application/x-www-form-urlencoded',
     }
     try {
       const response = await this.axios.post(keycloakTokenUrl, querystring.stringify(data), { headers, timeout: REQUEST_TIMEOUT_MS })
@@ -486,7 +492,7 @@ export class CheServerLoginManager {
 
   private async requestKeycloakAuth(keycloakTokenUrl: string, requestData: any): Promise<KeycloakAuthTokenResponse> {
     const headers = {
-      'Content-Type': 'application/x-www-form-urlencoded'
+      'Content-Type': 'application/x-www-form-urlencoded',
     }
     try {
       const response = await this.axios.post(keycloakTokenUrl, querystring.stringify(requestData), { headers, timeout: REQUEST_TIMEOUT_MS })
@@ -519,7 +525,6 @@ export class CheServerLoginManager {
       throw new Error(`Failed to get userdata from ${endpoint}. Cause: ${error.message}`)
     }
   }
-
 }
 
 /**
@@ -563,11 +568,12 @@ export async function getLoginData(cheApiEndpoint: string, accessToken: string |
  */
 export async function getCheApiEndpoint(flags: any): Promise<string> {
   const kube = new KubeHelper(flags)
-  if (!await kube.hasReadPermissionsForNamespace(flags.chenamespace)) {
+  const namespace = await findWorkingNamespace(flags)
+  if (!await kube.hasReadPermissionsForNamespace(namespace)) {
     throw new Error('Please provide server API URL argument')
   }
 
   // Retrieve API URL from routes
   const cheHelper = new CheHelper(flags)
-  return await cheHelper.cheURL(flags.chenamespace) + '/api'
+  return await cheHelper.cheURL(namespace) + '/api'
 }
