@@ -14,7 +14,6 @@ import { che as chetypes } from '@eclipse-che/api'
 import { CoreV1Api, V1Pod, Watch } from '@kubernetes/client-node'
 import axios, { AxiosInstance } from 'axios'
 import * as cp from 'child_process'
-import { cli } from 'cli-ux'
 import * as commandExists from 'command-exists'
 import * as fs from 'fs-extra'
 import * as https from 'https'
@@ -25,11 +24,12 @@ import * as path from 'path'
 import * as rimraf from 'rimraf'
 import * as unzipper from 'unzipper'
 import { OpenShiftHelper } from '../api/openshift'
-import { CHE_ROOT_CA_SECRET_NAME, DEFAULT_CA_CERT_FILE_NAME, OPERATOR_TEMPLATE_DIR } from '../constants'
+import { CHE_ROOT_CA_SECRET_NAME, DEFAULT_CHE_OLM_PACKAGE_NAME, DEFAULT_OPENSHIFT_OPERATORS_NS_NAME, OPERATOR_TEMPLATE_DIR } from '../constants'
 import { base64Decode, downloadFile } from '../util'
 import { CheApiClient } from './che-api-client'
-import { Devfile } from './devfile'
+import { Devfile } from './types/devfile'
 import { KubeHelper } from './kube'
+import { OperatorGroup, Subscription } from './types/olm'
 
 export class CheHelper {
   defaultCheResponseTimeoutMs = 3000
@@ -185,27 +185,6 @@ export class CheHelper {
     throw new Error(`Secret "${CHE_ROOT_CA_SECRET_NAME}" has invalid format: "ca.crt" key not found in data.`)
   }
 
-  async saveCheCaCert(cheCaCert: string, destination?: string): Promise<string> {
-    const cheCaCertFile = this.getTargetFile(destination)
-    fs.writeFileSync(cheCaCertFile, cheCaCert)
-    return cheCaCertFile
-  }
-
-  /**
-   * Handles certificate target location and returns string which points to the target file.
-   */
-  private getTargetFile(destination: string | undefined): string {
-    if (!destination) {
-      return path.join(os.tmpdir(), DEFAULT_CA_CERT_FILE_NAME)
-    }
-
-    if (fs.existsSync(destination)) {
-      return fs.lstatSync(destination).isDirectory() ? path.join(destination, DEFAULT_CA_CERT_FILE_NAME) : destination
-    }
-
-    throw new Error(`Given path \'${destination}\' doesn't exist.`)
-  }
-
   /**
    * Retrieves Keycloak admin user credentials.
    * Works only with installers which use Che CR (operator, olm).
@@ -239,7 +218,7 @@ export class CheHelper {
   }
 
   async chePluginRegistryK8sURL(namespace = ''): Promise<string> {
-    if (await this.kube.ingressExist('plugin-registry', namespace)) {
+    if (await this.kube.isIngressExist('plugin-registry', namespace)) {
       const protocol = await this.kube.getIngressProtocol('plugin-registry', namespace)
       const hostname = await this.kube.getIngressHost('plugin-registry', namespace)
       return `${protocol}://${hostname}`
@@ -259,7 +238,7 @@ export class CheHelper {
   async cheK8sURL(namespace = ''): Promise<string> {
     const ingress_names = ['che', 'che-ingress']
     for (const ingress_name of ingress_names) {
-      if (await this.kube.ingressExist(ingress_name, namespace)) {
+      if (await this.kube.isIngressExist(ingress_name, namespace)) {
         const protocol = await this.kube.getIngressProtocol(ingress_name, namespace)
         const hostname = await this.kube.getIngressHost(ingress_name, namespace)
         return `${protocol}://${hostname}`
@@ -403,22 +382,6 @@ export class CheHelper {
       () => { })
   }
 
-  /**
-   * Wait until workspace is in 'Active` state.
-   */
-  async waitNamespaceActive(namespaceName: string, intervalMs = 500, timeoutMs = 60000) {
-    const iterations = timeoutMs / intervalMs
-    for (let index = 0; index < iterations; index++) {
-      const namespace = await this.kube.getNamespace(namespaceName)
-      if (namespace && namespace.status && namespace.status.phase && namespace.status.phase === 'Active') {
-        return
-      }
-      await cli.wait(intervalMs)
-    }
-
-    throw new Error(`ERR_TIMEOUT: ${namespaceName} is not 'Active'.`)
-  }
-
   /**
    * Indicates if pod matches given labels.
    */
@@ -549,4 +512,47 @@ export class CheHelper {
       fs.moveSync(path.join(destDir, 'samples', 'org_v1_checlusterrestore.yaml'), path.join(destDir, 'crds', 'org.eclipse.che_v1_checlusterrestore_cr.yaml'))
     }
   }
+
+  async findCheOperatorSubscription(namespace: string): Promise<Subscription | undefined> {
+    try {
+      const subscriptions = await this.kube.listOperatorSubscriptions(namespace)
+      const cheSubscriptions = subscriptions.filter(subscription => subscription.spec.name && subscription.spec.name.includes(DEFAULT_CHE_OLM_PACKAGE_NAME))
+      if (cheSubscriptions.length > 1) {
+        throw new Error('Found more than one Che subscription')
+      }
+      if (cheSubscriptions.length === 1) {
+        return cheSubscriptions[0]
+      }
+      // No subscriptions found, check if Che is installed in all namespaces mode
+      if (namespace !== DEFAULT_OPENSHIFT_OPERATORS_NS_NAME) {
+        return this.findCheOperatorSubscription(DEFAULT_OPENSHIFT_OPERATORS_NS_NAME)
+      }
+    } catch {
+      // Do nothing, just return undefined
+    }
+  }
+
+  async findCheOperatorOperatorGroup(namespace: string): Promise<OperatorGroup | undefined> {
+    const subscription = await this.findCheOperatorSubscription(namespace)
+    if (!subscription || !subscription.status || !subscription.status.installedCSV) {
+      return
+    }
+
+    const csvName = subscription.status.installedCSV
+    if (subscription.metadata.namespace) {
+      namespace = subscription.metadata.namespace
+    }
+    const csv = await this.kube.getCSV(csvName, namespace)
+    if (!csv || !csv.metadata || !csv.metadata.annotations) {
+      return
+    }
+
+    const operatorGroupName = csv.metadata.annotations['olm.operatorGroup']
+    const operatorGroupNamespace = csv.metadata.annotations['olm.operatorNamespace']
+    if (!operatorGroupName || !operatorGroupNamespace) {
+      return
+    }
+
+    return this.kube.getOperatorGroup(operatorGroupName, operatorGroupNamespace)
+  }
 }
