@@ -1,19 +1,23 @@
-/*********************************************************************
- * Copyright (c) 2019 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 
 import { Command, flags } from '@oclif/command'
 import { cli } from 'cli-ux'
-import * as notifier from 'node-notifier'
 
 import { CheHelper } from '../../api/che'
-import { cheNamespace } from '../../common-flags'
+import { ChectlContext } from '../../api/context'
+import { cheNamespace, CHE_TELEMETRY } from '../../common-flags'
+import { DEFAULT_ANALYTIC_HOOK_NAME } from '../../constants'
+import { findWorkingNamespace } from '../../util'
 
 export default class Open extends Command {
   static description = 'Open CodeReady Workspaces dashboard'
@@ -21,12 +25,17 @@ export default class Open extends Command {
   static flags: flags.Input<any> = {
     help: flags.help({ char: 'h' }),
     chenamespace: cheNamespace,
+    telemetry: CHE_TELEMETRY,
   }
 
   async run() {
     const { flags } = this.parse(Open)
+    flags.chenamespace = await findWorkingNamespace(flags)
+    await ChectlContext.init(flags, this)
 
     try {
+      await this.config.runHook(DEFAULT_ANALYTIC_HOOK_NAME, { command: Open.id, flags })
+
       const cheHelper = new CheHelper(flags)
       const cheURL = await cheHelper.cheURL(flags.chenamespace)
       const dashboardUrl = `${cheURL}/dashboard/`
@@ -37,11 +46,6 @@ export default class Open extends Command {
       this.error(error)
     }
 
-    notifier.notify({
-      title: 'crwctl',
-      message: 'Command dashboard:open has completed successfully.'
-    })
-
     this.exit(0)
   }
 }
