@@ -15,18 +15,18 @@ import { boolean, string } from '@oclif/parser/lib/flags'
 import { cli } from 'cli-ux'
 import * as Listr from 'listr'
 import * as semver from 'semver'
-
-import { ChectlContext } from '../../api/context'
+import { ChectlContext, OLM } from '../../api/context'
 import { KubeHelper } from '../../api/kube'
-import { batch, cheDeployment, cheDeployVersion, cheNamespace, cheOperatorCRPatchYaml, cheOperatorCRYaml, CHE_OPERATOR_CR_PATCH_YAML_KEY, CHE_OPERATOR_CR_YAML_KEY, CHE_TELEMETRY, DEPLOY_VERSION_KEY, devWorkspaceControllerNamespace, k8sPodDownloadImageTimeout, K8SPODDOWNLOADIMAGETIMEOUT_KEY, k8sPodErrorRecheckTimeout, K8SPODERRORRECHECKTIMEOUT_KEY, k8sPodReadyTimeout, K8SPODREADYTIMEOUT_KEY, k8sPodWaitTimeout, K8SPODWAITTIMEOUT_KEY, listrRenderer, logsDirectory, LOG_DIRECTORY_KEY, skipKubeHealthzCheck as skipK8sHealthCheck } from '../../common-flags'
-import { DEFAULT_ANALYTIC_HOOK_NAME, DEFAULT_CHE_NAMESPACE, DEFAULT_OLM_SUGGESTED_NAMESPACE, DOCS_LINK_INSTALL_RUNNING_CHE_LOCALLY, MIN_CHE_OPERATOR_INSTALLER_VERSION, MIN_HELM_INSTALLER_VERSION, MIN_OLM_INSTALLER_VERSION } from '../../constants'
+import { batch, cheDeployment, cheDeployVersion, cheNamespace, cheOperatorCRPatchYaml, cheOperatorCRYaml, CHE_OPERATOR_CR_PATCH_YAML_KEY, CHE_OPERATOR_CR_YAML_KEY, CHE_TELEMETRY, DEPLOY_VERSION_KEY, k8sPodDownloadImageTimeout, K8SPODDOWNLOADIMAGETIMEOUT_KEY, k8sPodErrorRecheckTimeout, K8SPODERRORRECHECKTIMEOUT_KEY, k8sPodReadyTimeout, K8SPODREADYTIMEOUT_KEY, k8sPodWaitTimeout, K8SPODWAITTIMEOUT_KEY, listrRenderer, logsDirectory, LOG_DIRECTORY_KEY, skipKubeHealthzCheck as skipK8sHealthCheck } from '../../common-flags'
+import { DEFAULT_ANALYTIC_HOOK_NAME, DEFAULT_CHE_NAMESPACE, DEFAULT_OLM_SUGGESTED_NAMESPACE, DOCS_LINK_INSTALL_RUNNING_CHE_LOCALLY, MIN_CHE_OPERATOR_INSTALLER_VERSION, MIN_HELM_INSTALLER_VERSION, MIN_OLM_INSTALLER_VERSION, OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME } from '../../constants'
 import { CheTasks } from '../../tasks/che'
 import { DevWorkspaceTasks } from '../../tasks/component-installers/devfile-workspace-operator-installer'
-import { checkChectlAndCheVersionCompatibility, downloadTemplates, getPrintHighlightedMessagesTask, retrieveCheCaCertificateTask } from '../../tasks/installers/common-tasks'
+import { DexTasks } from '../../tasks/component-installers/dex'
+import { checkChectlAndCheVersionCompatibility, createNamespaceTask, downloadTemplates, getPrintHighlightedMessagesTask, retrieveCheCaCertificateTask } from '../../tasks/installers/common-tasks'
 import { InstallerTasks } from '../../tasks/installers/installer'
 import { ApiTasks } from '../../tasks/platforms/api'
 import { PlatformTasks } from '../../tasks/platforms/platform'
-import { askForChectlUpdateIfNeeded, getCommandSuccessMessage, getEmbeddedTemplatesDirectory, getProjectName, isKubernetesPlatformFamily, isOpenshiftPlatformFamily, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
+import { askForChectlUpdateIfNeeded, getCommandSuccessMessage, getEmbeddedTemplatesDirectory, getProjectName, getTlsSupport, isDevWorkspaceEnabled, isKubernetesPlatformFamily, isNativeUserModeEnabled, isOpenshiftPlatformFamily, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
 
 export default class Deploy extends Command {
   static description = 'Deploy CodeReady Workspaces server'
@@ -70,9 +70,9 @@ export default class Deploy extends Command {
     [LOG_DIRECTORY_KEY]: logsDirectory,
     multiuser: flags.boolean({
       char: 'm',
-      description: `Deploys CodeReady Workspaces in multi-user mode.
- 		                Note, this option is turned on by default.`,
+      description: 'Deprecated. The flag is ignored. CodeReady Workspaces is always deployed in multi-user mode.',
       default: false,
+      hidden: true,
     }),
     tls: flags.boolean({
       char: 's',
@@ -190,19 +190,18 @@ export default class Deploy extends Command {
       options: ['che-server', 'dev-workspace'],
       default: 'che-server',
     }),
-    'dev-workspace-controller-namespace': devWorkspaceControllerNamespace,
     telemetry: CHE_TELEMETRY,
     [DEPLOY_VERSION_KEY]: cheDeployVersion,
   }
 
   async setPlaformDefaults(flags: any, ctx: any): Promise<void> {
-    flags.tls = await this.checkTlsMode(ctx)
+    flags.tls = getTlsSupport(ctx)
     if (flags['self-signed-cert']) {
       this.warn('"self-signed-cert" flag is deprecated and has no effect. Autodetection is used instead.')
     }
 
     if (!flags.installer) {
-      await this.setDefaultInstaller(flags, ctx)
+      await setDefaultInstaller(flags)
       cli.info(`› Installer type is set to: '${flags.installer}'`)
     }
 
@@ -222,38 +221,6 @@ export default class Deploy extends Command {
     }
   }
 
-  /**
-   * Checks if TLS is disabled via operator custom resource.
-   * Returns true if TLS is enabled (or omitted) and false if it is explicitly disabled.
-   */
-  async checkTlsMode(ctx: any): Promise<boolean> {
-    const crPatch = ctx.crPatch
-    if (crPatch && crPatch.spec && crPatch.spec.server && crPatch.spec.server.tlsSupport === false) {
-      return false
-    }
-
-    const customCR = ctx.customCR
-    if (customCR && customCR.spec && customCR.spec.server && customCR.spec.server.tlsSupport === false) {
-      return false
-    }
-
-    return true
-  }
-
-  private isDevWorkspaceEnabled(ctx: any): boolean {
-    const crPatch = ctx.crPatch
-    if (crPatch && crPatch.spec && crPatch.spec.devWorkspace && crPatch.spec.devWorkspace.enable) {
-      return true
-    }
-
-    const customCR = ctx.customCR
-    if (customCR && customCR.spec && customCR.spec.devWorkspace && customCR.spec.devWorkspace.enable) {
-      return true
-    }
-
-    return false
-  }
-
   private checkCompatibility(flags: any) {
     if (flags.installer === 'operator' && flags[CHE_OPERATOR_CR_YAML_KEY]) {
       const ignoredFlags = []
@@ -265,7 +232,6 @@ export default class Deploy extends Command {
       flags.cheimage && ignoredFlags.push('--cheimage')
       flags.debug && ignoredFlags.push('--debug')
       flags.domain && ignoredFlags.push('--domain')
-      flags.multiuser && ignoredFlags.push('--multiuser')
 
       if (ignoredFlags.length) {
         this.warn(`--${CHE_OPERATOR_CR_YAML_KEY} is used. The following flag(s) will be ignored: ${ignoredFlags.join('\t')}`)
@@ -288,46 +254,47 @@ export default class Deploy extends Command {
         this.error(`🛑 The specified installer ${flags.installer} does not support Minishift`)
       }
 
-      if (flags['catalog-source-name'] && flags['catalog-source-yaml']) {
-        this.error('should be provided only one argument: "catalog-source-name" or "catalog-source-yaml"')
+      if (flags[OLM.CHANNEL] === OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME && isKubernetesPlatformFamily(flags.platform)) {
+        this.error('"stable-all-namespaces" channel is supported only in "openshift" platform')
+      }
+
+      if (flags[OLM.CATALOG_SOURCE_NAME] && flags[OLM.CATALOG_SOURCE_YAML]) {
+        this.error(`should be provided only one argument: "${OLM.CATALOG_SOURCE_NAME}" or "${OLM.CATALOG_SOURCE_YAML}"`)
       }
       if (flags.version) {
-        if (flags['starting-csv']) {
-          this.error('"starting-csv" and "version" flags are mutually exclusive. Please specify only one of them.')
+        if (flags[OLM.STARTING_CSV]) {
+          this.error(`"${OLM.STARTING_CSV}" and "version" flags are mutually exclusive. Please specify only one of them.`)
         }
-        if (flags['olm-channel']) {
-          this.error('"starting-csv" and "version" flags are mutually exclusive. Use "starting-csv" with "olm-channel" flag.')
-        }
-        if (flags['auto-update']) {
-          this.error('enabled "auto-update" flag cannot be used with version flag. Deploy latest version instead.')
+        if (flags[OLM.AUTO_UPDATE]) {
+          this.error(`enabled "${OLM.AUTO_UPDATE}" flag cannot be used with version flag. Deploy latest version instead.`)
         }
       }
 
-      if (!flags['package-manifest-name'] && flags['catalog-source-yaml']) {
-        this.error('you need to define "package-manifest-name" flag to use "catalog-source-yaml".')
+      if (!flags[OLM.PACKAGE_MANIFEST_NAME] && flags[OLM.CATALOG_SOURCE_YAML]) {
+        this.error(`you need to define "${OLM.PACKAGE_MANIFEST_NAME}" flag to use "${OLM.CATALOG_SOURCE_YAML}".`)
       }
-      if (!flags['olm-channel'] && flags['catalog-source-yaml']) {
-        this.error('you need to define "olm-channel" flag to use "catalog-source-yaml".')
+      if (!flags[OLM.CHANNEL] && flags[OLM.CATALOG_SOURCE_YAML]) {
+        this.error(`you need to define "${OLM.CHANNEL}" flag to use "${OLM.CATALOG_SOURCE_YAML}".`)
       }
     } else {
       // Not OLM installer
-      if (flags['starting-csv']) {
-        this.error('"starting-csv" flag should be used only with "olm" installer.')
+      if (flags[OLM.STARTING_CSV]) {
+        this.error(`"${OLM.STARTING_CSV}" flag should be used only with "olm" installer.`)
       }
-      if (flags['catalog-source-yaml']) {
-        this.error('"catalog-source-yaml" flag should be used only with "olm" installer.')
+      if (flags[OLM.CATALOG_SOURCE_YAML]) {
+        this.error(`"${OLM.CATALOG_SOURCE_YAML}" flag should be used only with "olm" installer.`)
       }
-      if (flags['olm-channel']) {
-        this.error('"olm-channel" flag should be used only with "olm" installer.')
+      if (flags[OLM.CHANNEL]) {
+        this.error(`"${OLM.CHANNEL}" flag should be used only with "olm" installer.`)
       }
-      if (flags['package-manifest-name']) {
-        this.error('"package-manifest-name" flag should be used only with "olm" installer.')
+      if (flags[OLM.PACKAGE_MANIFEST_NAME]) {
+        this.error(`"${OLM.PACKAGE_MANIFEST_NAME}" flag should be used only with "olm" installer.`)
       }
-      if (flags['catalog-source-name']) {
-        this.error('"catalog-source-name" flag should be used only with "olm" installer.')
+      if (flags[OLM.CATALOG_SOURCE_NAME]) {
+        this.error(`"${OLM.CATALOG_SOURCE_NAME}" flag should be used only with "olm" installer.`)
       }
-      if (flags['catalog-source-namespace']) {
-        this.error('"package-manifest-name" flag should be used only with "olm" installer.')
+      if (flags[OLM.CATALOG_SOURCE_NAMESPACE]) {
+        this.error(`"${OLM.CATALOG_SOURCE_NAMESPACE}" flag should be used only with "olm" installer.`)
       }
       if (flags['cluster-monitoring'] && flags.platform !== 'openshift') {
         this.error('"cluster-monitoring" flag should be used only with "olm" installer and "openshift" platform.')
@@ -378,8 +345,21 @@ export default class Deploy extends Command {
     await this.setPlaformDefaults(flags, ctx)
     await this.config.runHook(DEFAULT_ANALYTIC_HOOK_NAME, { command: Deploy.id, flags })
 
+    if (!flags.batch && flags.installer === 'helm') {
+      if (!await cli.confirm('\'helm\' installer is deprecated. Do you want to proceed? [y/n]')) {
+        cli.exit(0)
+      }
+    }
+
+    if (!flags.batch && isKubernetesPlatformFamily(flags.platform) && (isDevWorkspaceEnabled(ctx) || flags['workspace-engine'] === 'dev-workspace')) {
+      if (!await cli.confirm('DevWorkspace is experimental feature. It requires direct access to the underlying infrastructure REST API.\nThis results in huge privilege escalation. Do you want to proceed? [y/n]')) {
+        cli.exit(0)
+      }
+    }
+
+    const dexTasks = new DexTasks(flags)
     const cheTasks = new CheTasks(flags)
-    const platformTasks = new PlatformTasks()
+    const platformTasks = new PlatformTasks(flags)
     const installerTasks = new InstallerTasks()
     const apiTasks = new ApiTasks()
     const devWorkspaceTasks = new DevWorkspaceTasks(flags)
@@ -398,10 +378,16 @@ export default class Deploy extends Command {
     preInstallTasks.add(downloadTemplates(flags))
     preInstallTasks.add({
       title: '🧪  DevWorkspace engine (experimental / technology preview) 🚨',
-      enabled: () => (this.isDevWorkspaceEnabled(ctx) || flags['workspace-engine'] === 'dev-workspace') && !ctx.isOpenShift,
+      enabled: () => (isDevWorkspaceEnabled(ctx) || flags['workspace-engine'] === 'dev-workspace') && !ctx.isOpenShift,
       task: () => new Listr(devWorkspaceTasks.getInstallTasks(flags)),
     })
-    const installTasks = new Listr(installerTasks.installTasks(flags, this), ctx.listrOptions)
+
+    const installTasks = new Listr(undefined, ctx.listrOptions)
+    installTasks.add([createNamespaceTask(flags.chenamespace, this.getNamespaceLabels(flags))])
+    if (isKubernetesPlatformFamily(flags.platform) && isNativeUserModeEnabled(ctx)) {
+      installTasks.add(dexTasks.getInstallTasks())
+    }
+    installTasks.add(await installerTasks.installTasks(flags, this))
 
     // Post Install Checks
     const postInstallTasks = new Listr([
@@ -440,27 +426,37 @@ export default class Deploy extends Command {
       this.error(wrapCommandError(err))
     }
 
-    notifyCommandCompletedSuccessfully()
+    if (!flags.batch) {
+      notifyCommandCompletedSuccessfully()
+    }
     this.exit(0)
   }
 
-  /**
-   * Sets default installer which is `olm` for OpenShift 4 with stable version of crwctl
-   * and `operator` for other cases.
-   */
-  async setDefaultInstaller(flags: any, _ctx: any): Promise<void> {
-    const kubeHelper = new KubeHelper(flags)
-
-    const isOlmPreinstalled = await kubeHelper.isPreInstalledOLM()
-    if ((flags['catalog-source-name'] || flags['catalog-source-yaml']) && isOlmPreinstalled) {
-      flags.installer = 'olm'
-      return
-    }
-
-    if (flags.platform === 'openshift' && await kubeHelper.isOpenShift4() && isOlmPreinstalled) {
-      flags.installer = 'olm'
-    } else {
-      flags.installer = 'operator'
+  private getNamespaceLabels(flags: any): any {
+    // The label values must be strings
+    if (flags['cluster-monitoring'] && flags.platform === 'openshift') {
+      return { 'openshift.io/cluster-monitoring': 'true' }
     }
+    return {}
+  }
+}
+
+/**
+ * Sets default installer which is `olm` for OpenShift 4 with stable version of crwctl
+ * and `operator` for other cases.
+ */
+export async function setDefaultInstaller(flags: any): Promise<void> {
+  const kubeHelper = new KubeHelper(flags)
+
+  const isOlmPreinstalled = await kubeHelper.isPreInstalledOLM()
+  if ((flags[OLM.CATALOG_SOURCE_NAME] || flags[OLM.CATALOG_SOURCE_YAML]) && isOlmPreinstalled) {
+    flags.installer = 'olm'
+    return
+  }
+
+  if (flags.platform === 'openshift' && await kubeHelper.isOpenShift4() && isOlmPreinstalled) {
+    flags.installer = 'olm'
+  } else {
+    flags.installer = 'operator'
   }
 }
