@@ -1,26 +1,22 @@
-/*********************************************************************
- * Copyright (c) 2019 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 import { boolean, string } from '@oclif/parser/lib/flags'
 
-import { DEFAULT_CHE_NAMESPACE, DEFAULT_DEV_WORKSPACE_CONTROLLER_NAMESPACE, DEFAULT_K8S_POD_ERROR_RECHECK_TIMEOUT, DEFAULT_K8S_POD_WAIT_TIMEOUT, DOC_LINK_OBTAIN_ACCESS_TOKEN, DOC_LINK_OBTAIN_ACCESS_TOKEN_OAUTH } from './constants'
+import { DEFAULT_CHE_NAMESPACE, DEFAULT_K8S_POD_ERROR_RECHECK_TIMEOUT, DEFAULT_K8S_POD_WAIT_TIMEOUT, DOC_LINK_OBTAIN_ACCESS_TOKEN, DOC_LINK_OBTAIN_ACCESS_TOKEN_OAUTH } from './constants'
 
 export const cheNamespace = string({
   char: 'n',
   description: `CodeReady Workspaces Openshift Project. Default to '${DEFAULT_CHE_NAMESPACE}'`,
-  env: 'CHE_NAMESPACE'
-})
-
-export const devWorkspaceControllerNamespace = string({
-  description: 'Namespace for the DevWorkspace controller.  This parameter is used only when the workspace engine is the DevWorkspace',
-  default: DEFAULT_DEV_WORKSPACE_CONTROLLER_NAMESPACE,
-  env: 'DEV_WORKSPACE_OPERATOR_NAMESPACE',
+  env: 'CHE_NAMESPACE',
 })
 
 export const batch = boolean({
@@ -32,7 +28,7 @@ export const batch = boolean({
 export const cheDeployment = string({
   description: 'CodeReady Workspaces deployment name',
   default: 'codeready',
-  env: 'CHE_DEPLOYMENT'
+  env: 'CHE_DEPLOYMENT',
 })
 
 export const listrRenderer = string({
@@ -45,12 +41,12 @@ export const listrRenderer = string({
 export const ACCESS_TOKEN_KEY = 'access-token'
 export const accessToken = string({
   description: `CodeReady Workspaces OIDC Access Token. See the documentation how to obtain token: ${DOC_LINK_OBTAIN_ACCESS_TOKEN} and ${DOC_LINK_OBTAIN_ACCESS_TOKEN_OAUTH}.`,
-  env: 'CHE_ACCESS_TOKEN'
+  env: 'CHE_ACCESS_TOKEN',
 })
 
 export const skipKubeHealthzCheck = boolean({
   description: 'Skip Kubernetes health check',
-  default: false
+  default: false,
 })
 
 export const CHE_API_ENDPOINT_KEY = 'che-api-endpoint'
@@ -77,7 +73,7 @@ export const assumeYes = boolean({
 export const CHE_OPERATOR_CR_YAML_KEY = 'che-operator-cr-yaml'
 export const cheOperatorCRYaml = string({
   description: 'Path to a yaml file that defines a CheCluster used by the operator. This parameter is used only when the installer is the \'operator\' or the \'olm\'.',
-  default: ''
+  default: '',
 })
 
 export const USERNAME_KEY = 'username'
@@ -91,37 +87,37 @@ export const username = string({
 export const K8SPODWAITTIMEOUT_KEY = 'k8spodwaittimeout'
 export const k8sPodWaitTimeout = string({
   description: 'Waiting time for Pod scheduled condition (in milliseconds)',
-  default: `${DEFAULT_K8S_POD_WAIT_TIMEOUT}`
+  default: `${DEFAULT_K8S_POD_WAIT_TIMEOUT}`,
 })
 
 export const K8SPODDOWNLOADIMAGETIMEOUT_KEY = 'k8spoddownloadimagetimeout'
 export const k8sPodDownloadImageTimeout = string({
   description: 'Waiting time for Pod downloading image (in milliseconds)',
-  default: `${DEFAULT_K8S_POD_WAIT_TIMEOUT}`
+  default: `${DEFAULT_K8S_POD_WAIT_TIMEOUT}`,
 })
 
 export const K8SPODREADYTIMEOUT_KEY = 'k8spodreadytimeout'
 export const k8sPodReadyTimeout = string({
   description: 'Waiting time for Pod Ready condition (in milliseconds)',
-  default: `${DEFAULT_K8S_POD_WAIT_TIMEOUT}`
+  default: `${DEFAULT_K8S_POD_WAIT_TIMEOUT}`,
 })
 
 export const K8SPODERRORRECHECKTIMEOUT_KEY = 'k8spoderrorrechecktimeout'
 export const k8sPodErrorRecheckTimeout = string({
   description: 'Waiting time for Pod rechecking error (in milliseconds)',
-  default: `${DEFAULT_K8S_POD_ERROR_RECHECK_TIMEOUT}`
+  default: `${DEFAULT_K8S_POD_ERROR_RECHECK_TIMEOUT}`,
 })
 
 export const LOG_DIRECTORY_KEY = 'directory'
 export const logsDirectory = string({
   char: 'd',
   description: 'Directory to store logs into',
-  env: 'CHE_LOGS'
+  env: 'CHE_LOGS',
 })
 
 export const CHE_TELEMETRY = string({
   description: 'Enable or disable telemetry. This flag skips a prompt and enable/disable telemetry',
-  options: ['on', 'off']
+  options: ['on', 'off'],
 })
 
 export const DEPLOY_VERSION_KEY = 'version'
