@@ -15,14 +15,22 @@ import { cli } from 'cli-ux'
 import * as yaml from 'js-yaml'
 import Listr = require('listr')
 import * as path from 'path'
-
+import { OLM, OLMInstallationUpdate } from '../../api/context'
+import { CheHelper } from '../../api/che'
 import { KubeHelper } from '../../api/kube'
-import { CatalogSource, Subscription } from '../../api/typings/olm'
+import { CatalogSource, Subscription } from '../../api/types/olm'
 import { VersionHelper } from '../../api/version'
-import { CUSTOM_CATALOG_SOURCE_NAME, CVS_PREFIX, DEFAULT_CHE_OLM_PACKAGE_NAME, DEFAULT_OLM_KUBERNETES_NAMESPACE, DEFAULT_OPENSHIFT_MARKET_PLACE_NAMESPACE, KUBERNETES_OLM_CATALOG, NIGHTLY_CATALOG_SOURCE_NAME, OLM_NIGHTLY_CHANNEL_NAME, OLM_STABLE_CHANNEL_NAME, OPENSHIFT_OLM_CATALOG, OPERATOR_GROUP_NAME, SUBSCRIPTION_NAME } from '../../constants'
-import { isKubernetesPlatformFamily } from '../../util'
+import { CUSTOM_CATALOG_SOURCE_NAME, CVS_PREFIX, DEFAULT_CHE_NAMESPACE, DEFAULT_CHE_OLM_PACKAGE_NAME, DEFAULT_OLM_KUBERNETES_NAMESPACE, DEFAULT_OPENSHIFT_MARKET_PLACE_NAMESPACE, DEFAULT_OPENSHIFT_OPERATORS_NS_NAME, KUBERNETES_OLM_CATALOG, NEXT_CATALOG_SOURCE_NAME, OLM_NEXT_CHANNEL_NAME, OLM_STABLE_CHANNEL_NAME, OPENSHIFT_OLM_CATALOG, OPERATOR_GROUP_NAME, OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME, DEFAULT_CHE_OPERATOR_SUBSCRIPTION_NAME, OLM_NEXT_ALL_NAMESPACES_CHANNEL_NAME } from '../../constants'
+import { getEmbeddedTemplatesDirectory, isKubernetesPlatformFamily } from '../../util'
 
-import { createEclipseCheCluster, createNamespaceTask, patchingEclipseCheCluster } from './common-tasks'
+import { createEclipseCheCluster, patchingEclipseCheCluster } from './common-tasks'
+
+export const TASK_TITLE_SET_CUSTOM_OPERATOR_IMAGE = 'Set custom operator image'
+export const TASK_TITLE_CREATE_CUSTOM_CATALOG_SOURCE_FROM_FILE = 'Create custom catalog source from file'
+export const TASK_TITLE_PREPARE_CHE_CLUSTER_CR = 'Prepare CodeReady Workspaces cluster CR'
+
+export const TASK_TITLE_DELETE_CUSTOM_CATALOG_SOURCE = `Delete(OLM) custom catalog source ${CUSTOM_CATALOG_SOURCE_NAME}`
+export const TASK_TITLE_DELETE_NIGHTLY_CATALOG_SOURCE = `Delete(OLM) nigthly catalog source ${NEXT_CATALOG_SOURCE_NAME}`
 
 export class OLMTasks {
   prometheusRoleName = 'prometheus-k8s'
@@ -32,16 +40,16 @@ export class OLMTasks {
   /**
    * Returns list of tasks which perform preflight platform checks.
    */
-  startTasks(flags: any, command: Command): Listr {
+  startTasks(flags: any, command: Command): Listr.ListrTask<any>[] {
     const kube = new KubeHelper(flags)
-    return new Listr([
+    const che = new CheHelper(flags)
+    return [
       this.isOlmPreInstalledTask(command, kube),
-      createNamespaceTask(flags.chenamespace, this.getOlmNamespaceLabels(flags)),
       {
         enabled: () => flags['cluster-monitoring'] && flags.platform === 'openshift',
         title: `Create Role ${this.prometheusRoleName} in namespace ${flags.chenamespace}`,
         task: async (_ctx: any, task: any) => {
-          const yamlFilePath = path.join(flags.templates, '..', 'installers', 'prometheus-role.yaml')
+          const yamlFilePath = path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'prometheus-role.yaml')
           const exist = await kube.roleExist(this.prometheusRoleName, flags.chenamespace)
           if (exist) {
             task.title = `${task.title}...It already exists.`
@@ -56,7 +64,7 @@ export class OLMTasks {
         title: `Create RoleBinding ${this.prometheusRoleBindingName} in namespace ${flags.chenamespace}`,
         task: async (_ctx: any, task: any) => {
           const exist = await kube.roleBindingExist(this.prometheusRoleBindingName, flags.chenamespace)
-          const yamlFilePath = path.join(flags.templates, '..', 'installers', 'prometheus-role-binding.yaml')
+          const yamlFilePath = path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'prometheus-role-binding.yaml')
 
           if (exist) {
             task.title = `${task.title}...It already exists.`
@@ -66,43 +74,43 @@ export class OLMTasks {
           }
         },
       },
-      {
-        title: 'Create operator group',
-        task: async (_ctx: any, task: any) => {
-          if (await kube.operatorGroupExists(OPERATOR_GROUP_NAME, flags.chenamespace)) {
-            task.title = `${task.title}...It already exists.`
-          } else {
-            await kube.createOperatorGroup(OPERATOR_GROUP_NAME, flags.chenamespace)
-            task.title = `${task.title}...created new one.`
-          }
-        },
-      },
       {
         title: 'Configure context information',
         task: async (ctx: any, task: any) => {
+          ctx.operatorNamespace = flags.chenamespace || DEFAULT_CHE_NAMESPACE
+          if (flags[OLM.CHANNEL] === OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME || flags[OLM.CHANNEL] === OLM_NEXT_ALL_NAMESPACES_CHANNEL_NAME) {
+            ctx.operatorNamespace = DEFAULT_OPENSHIFT_OPERATORS_NS_NAME
+          }
+
           ctx.defaultCatalogSourceNamespace = isKubernetesPlatformFamily(flags.platform) ? DEFAULT_OLM_KUBERNETES_NAMESPACE : DEFAULT_OPENSHIFT_MARKET_PLACE_NAMESPACE
           // catalog source name for stable Che version
           ctx.catalogSourceNameStable = isKubernetesPlatformFamily(flags.platform) ? KUBERNETES_OLM_CATALOG : OPENSHIFT_OLM_CATALOG
 
-          ctx.sourceName = flags['catalog-source-name'] || CUSTOM_CATALOG_SOURCE_NAME
+          ctx.sourceName = flags[OLM.CATALOG_SOURCE_NAME] || CUSTOM_CATALOG_SOURCE_NAME
           ctx.generalPlatformName = isKubernetesPlatformFamily(flags.platform) ? 'kubernetes' : 'openshift'
 
           if (flags.version) {
             // Convert version flag to channel (see subscription object), starting CSV and approval starategy
             flags.version = VersionHelper.removeVPrefix(flags.version, true)
             // Need to point to specific CSV
-            ctx.startingCSV = `eclipse-che.v${flags.version}`
+            if (flags[OLM.STARTING_CSV]) {
+              ctx.startingCSV = flags[OLM.STARTING_CSV]
+            } else if (flags[OLM.CHANNEL] === OLM_STABLE_CHANNEL_NAME) {
+              ctx.startingCSV = `eclipse-che.v${flags.version}`
+            } else if (flags[OLM.CHANNEL] === OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME) {
+              ctx.startingCSV = `eclipse-che-preview-openshift.v${flags.version}-all-namespaces`
+            } // else use latest in the channel
             // Set approval starategy to manual to prevent autoupdate to the latest version right before installation
-            ctx.approvalStarategy = 'Manual'
+            ctx.approvalStarategy = OLMInstallationUpdate.MANUAL
           } else {
-            ctx.startingCSV = flags['starting-csv']
+            ctx.startingCSV = flags[OLM.STARTING_CSV]
             if (ctx.startingCSV) {
-              // Ignore auto-update flag, otherwise it will automatically update to the latest version and starting-csv will not have any effect.
-              ctx.approvalStarategy = 'Manual'
-            } else if (flags['auto-update'] === undefined) {
-              ctx.approvalStarategy = 'Automatic'
+              // Ignore auto-update flag, otherwise it will automatically update to the latest version and 'starting-csv' will not have any effect.
+              ctx.approvalStarategy = OLMInstallationUpdate.MANUAL
+            } else if (flags[OLM.AUTO_UPDATE] === undefined) {
+              ctx.approvalStarategy = OLMInstallationUpdate.AUTO
             } else {
-              ctx.approvalStarategy = flags['auto-update'] ? 'Automatic' : 'Manual'
+              ctx.approvalStarategy = flags[OLM.AUTO_UPDATE] ? OLMInstallationUpdate.AUTO : OLMInstallationUpdate.MANUAL
             }
           }
 
@@ -110,24 +118,38 @@ export class OLMTasks {
         },
       },
       {
-        enabled: () => !VersionHelper.isDeployingStableVersion(flags) && !flags['catalog-source-name'] && !flags['catalog-source-yaml'] && flags['olm-channel'] !== OLM_STABLE_CHANNEL_NAME,
-        title: `Create nightly index CatalogSource in the namespace ${flags.chenamespace}`,
+        title: 'Create operator group',
+        // 'stable-all-namespaces' and 'next-all-namespaces' channels install the operator in openshift-operators namespace and there already exists a pre-created operator-group.
+        enabled: (ctx: any) => ctx.operatorNamespace !== DEFAULT_OPENSHIFT_OPERATORS_NS_NAME,
+        task: async (_ctx: any, task: any) => {
+          const operatorGroup = await che.findCheOperatorOperatorGroup(flags.chenamespace)
+          if (operatorGroup) {
+            task.title = `${task.title}...it already exists: ${operatorGroup.metadata.name}`
+          } else {
+            await kube.createOperatorGroup(OPERATOR_GROUP_NAME, flags.chenamespace)
+            task.title = `${task.title}...created a new one: ${OPERATOR_GROUP_NAME}`
+          }
+        },
+      },
+      {
+        enabled: () => !VersionHelper.isDeployingStableVersion(flags) && !flags[OLM.CATALOG_SOURCE_NAME] && !flags[OLM.CATALOG_SOURCE_YAML] && flags[OLM.CHANNEL] !== OLM_STABLE_CHANNEL_NAME,
+        title: 'Create next index CatalogSource',
         task: async (ctx: any, task: any) => {
-          if (!await kube.catalogSourceExists(NIGHTLY_CATALOG_SOURCE_NAME, flags.chenamespace)) {
+          if (!await kube.catalogSourceExists(NEXT_CATALOG_SOURCE_NAME, ctx.operatorNamespace)) {
             const catalogSourceImage = `quay.io/eclipse/eclipse-che-${ctx.generalPlatformName}-opm-catalog:preview`
-            const nigthlyCatalogSource = this.constructIndexCatalogSource(flags.chenamespace, catalogSourceImage)
-            await kube.createCatalogSource(nigthlyCatalogSource)
-            await kube.waitCatalogSource(flags.chenamespace, NIGHTLY_CATALOG_SOURCE_NAME)
+            const nextCatalogSource = this.constructIndexCatalogSource(ctx.operatorNamespace, catalogSourceImage)
+            await kube.createCatalogSource(nextCatalogSource)
+            await kube.waitCatalogSource(ctx.operatorNamespace, NEXT_CATALOG_SOURCE_NAME)
           } else {
             task.title = `${task.title}...It already exists.`
           }
         },
       },
       {
-        enabled: () => flags['catalog-source-yaml'],
-        title: 'Create custom catalog source from file',
+        title: TASK_TITLE_CREATE_CUSTOM_CATALOG_SOURCE_FROM_FILE,
+        enabled: () => flags[OLM.CATALOG_SOURCE_YAML],
         task: async (ctx: any, task: any) => {
-          const customCatalogSource: CatalogSource = kube.readCatalogSourceFromFile(flags['catalog-source-yaml'])
+          const customCatalogSource: CatalogSource = kube.readCatalogSourceFromFile(flags[OLM.CATALOG_SOURCE_YAML])
           if (!await kube.catalogSourceExists(customCatalogSource.metadata!.name!, flags.chenamespace)) {
             customCatalogSource.metadata.name = ctx.sourceName
             customCatalogSource.metadata.namespace = flags.chenamespace
@@ -142,51 +164,57 @@ export class OLMTasks {
       {
         title: 'Create operator subscription',
         task: async (ctx: any, task: any) => {
-          if (await kube.operatorSubscriptionExists(SUBSCRIPTION_NAME, flags.chenamespace)) {
+          let subscription = await che.findCheOperatorSubscription(ctx.operatorNamespace)
+          if (subscription) {
+            ctx.subscriptionName = subscription.metadata.name
             task.title = `${task.title}...It already exists.`
-          } else {
-            let subscription: Subscription
-            if (flags['catalog-source-yaml'] || flags['catalog-source-name']) {
-              // custom Che CatalogSource
-              const catalogSourceNamespace = flags['catalog-source-namespace'] || flags.chenamespace
-              subscription = this.constructSubscription(SUBSCRIPTION_NAME, flags['package-manifest-name'], flags.chenamespace, catalogSourceNamespace, flags['olm-channel'], ctx.sourceName, ctx.approvalStarategy, ctx.startingCSV)
-            } else if (VersionHelper.isDeployingStableVersion(flags) || flags['olm-channel'] === OLM_STABLE_CHANNEL_NAME) {
-              // stable Che CatalogSource
-              subscription = this.constructSubscription(SUBSCRIPTION_NAME, DEFAULT_CHE_OLM_PACKAGE_NAME, flags.chenamespace, ctx.defaultCatalogSourceNamespace, OLM_STABLE_CHANNEL_NAME, ctx.catalogSourceNameStable, ctx.approvalStarategy, ctx.startingCSV)
-            } else {
-              // nightly Che CatalogSource
-              subscription = this.constructSubscription(SUBSCRIPTION_NAME, `eclipse-che-preview-${ctx.generalPlatformName}`, flags.chenamespace, flags.chenamespace, OLM_NIGHTLY_CHANNEL_NAME, NIGHTLY_CATALOG_SOURCE_NAME, ctx.approvalStarategy, ctx.startingCSV)
-            }
-            await kube.createOperatorSubscription(subscription)
-            task.title = `${task.title}...created new one.`
+            return
           }
+          ctx.subscriptionName = DEFAULT_CHE_OPERATOR_SUBSCRIPTION_NAME
+          const channel = flags[OLM.CHANNEL]
+
+          if (flags[OLM.CATALOG_SOURCE_YAML] || flags[OLM.CATALOG_SOURCE_NAME]) {
+            // custom Che CatalogSource
+            const catalogSourceNamespace = flags[OLM.CATALOG_SOURCE_NAMESPACE] || ctx.operatorNamespace
+            subscription = this.constructSubscription(ctx.subscriptionName, flags[OLM.PACKAGE_MANIFEST_NAME], ctx.operatorNamespace, catalogSourceNamespace, channel || OLM_STABLE_CHANNEL_NAME, ctx.sourceName, ctx.approvalStarategy, ctx.startingCSV)
+          } else if (channel === OLM_STABLE_CHANNEL_NAME || channel === OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME || (VersionHelper.isDeployingStableVersion(flags) && !channel)) {
+            // stable Che CatalogSource
+            subscription = this.constructSubscription(ctx.subscriptionName, DEFAULT_CHE_OLM_PACKAGE_NAME, ctx.operatorNamespace, ctx.defaultCatalogSourceNamespace, channel || OLM_STABLE_CHANNEL_NAME, ctx.catalogSourceNameStable, ctx.approvalStarategy, ctx.startingCSV)
+          } else if (channel === OLM_NEXT_CHANNEL_NAME || channel === OLM_NEXT_ALL_NAMESPACES_CHANNEL_NAME || !channel) {
+            // next Che CatalogSource
+            subscription = this.constructSubscription(ctx.subscriptionName, `eclipse-che-preview-${ctx.generalPlatformName}`, ctx.operatorNamespace, ctx.operatorNamespace, channel || OLM_NEXT_CHANNEL_NAME, NEXT_CATALOG_SOURCE_NAME, ctx.approvalStarategy, ctx.startingCSV)
+          } else {
+            throw new Error(`Unknown OLM channel ${flags[OLM.CHANNEL]}`)
+          }
+          await kube.createOperatorSubscription(subscription)
+          task.title = `${task.title}...created new one.`
         },
       },
       {
         title: 'Wait while subscription is ready',
         task: async (ctx: any, task: any) => {
-          const installPlan = await kube.waitOperatorSubscriptionReadyForApproval(flags.chenamespace, SUBSCRIPTION_NAME, 600)
+          const installPlan = await kube.waitOperatorSubscriptionReadyForApproval(ctx.operatorNamespace, ctx.subscriptionName, 600)
           ctx.installPlanName = installPlan.name
           task.title = `${task.title}...done.`
         },
       },
       {
         title: 'Approve installation',
-        enabled: ctx => ctx.approvalStarategy === 'Manual',
+        enabled: ctx => ctx.approvalStarategy === OLMInstallationUpdate.MANUAL,
         task: async (ctx: any, task: any) => {
-          await kube.approveOperatorInstallationPlan(ctx.installPlanName, flags.chenamespace)
+          await kube.approveOperatorInstallationPlan(ctx.installPlanName, ctx.operatorNamespace)
           task.title = `${task.title}...done.`
         },
       },
       {
         title: 'Wait while operator installed',
         task: async (ctx: any, task: any) => {
-          await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, flags.chenamespace)
+          await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, ctx.operatorNamespace)
           task.title = `${task.title}...done.`
         },
       },
       {
-        title: 'Set custom operator image',
+        title: TASK_TITLE_SET_CUSTOM_OPERATOR_IMAGE,
         enabled: () => flags['che-operator-image'],
         task: async (_ctx: any, task: any) => {
           const csvList = await kube.getClusterServiceVersions(flags.chenamespace)
@@ -200,7 +228,7 @@ export class OLMTasks {
         },
       },
       {
-        title: 'Prepare CodeReady Workspaces cluster CR',
+        title: TASK_TITLE_PREPARE_CHE_CLUSTER_CR,
         task: async (ctx: any, task: any) => {
           const cheCluster = await kube.getCheCluster(flags.chenamespace)
           if (cheCluster) {
@@ -209,35 +237,29 @@ export class OLMTasks {
           }
 
           if (!ctx.customCR) {
-            ctx.defaultCR = await this.getCRFromCSV(kube, flags.chenamespace)
+            ctx.defaultCR = await this.getCRFromCSV(kube, ctx.operatorNamespace, ctx.subscriptionName)
           }
 
           task.title = `${task.title}...Done.`
         },
       },
       createEclipseCheCluster(flags, kube),
-    ], { renderer: flags['listr-renderer'] as any })
+    ]
   }
 
   preUpdateTasks(flags: any, command: Command): Listr {
     const kube = new KubeHelper(flags)
+    const che = new CheHelper(flags)
     return new Listr([
       this.isOlmPreInstalledTask(command, kube),
-      {
-        title: 'Check if operator group exists',
-        task: async (_ctx: any, task: any) => {
-          if (!await kube.operatorGroupExists(OPERATOR_GROUP_NAME, flags.chenamespace)) {
-            command.error(`Unable to find operator group ${OPERATOR_GROUP_NAME}`)
-          }
-          task.title = `${task.title}...done.`
-        },
-      },
       {
         title: 'Check if operator subscription exists',
-        task: async (_ctx: any, task: any) => {
-          if (!await kube.operatorSubscriptionExists(SUBSCRIPTION_NAME, flags.chenamespace)) {
-            command.error(`Unable to find operator subscription ${SUBSCRIPTION_NAME}`)
+        task: async (ctx: any, task: any) => {
+          const subscription = await che.findCheOperatorSubscription(flags.chenamespace)
+          if (!subscription) {
+            command.error('Unable to find operator subscription')
           }
+          ctx.operatorNamespace = subscription.metadata.namespace
           task.title = `${task.title}...done.`
         },
       },
@@ -246,11 +268,13 @@ export class OLMTasks {
 
   updateTasks(flags: any, command: Command): Listr {
     const kube = new KubeHelper(flags)
+    const che = new CheHelper(flags)
     return new Listr([
       {
         title: 'Get operator installation plan',
         task: async (ctx: any, task: any) => {
-          const subscription: Subscription = await kube.getOperatorSubscription(SUBSCRIPTION_NAME, flags.chenamespace)
+          // We can be sure that the subscription exist, because it was checked in preupdate tasks
+          const subscription: Subscription = (await che.findCheOperatorSubscription(ctx.operatorNamespace))!
 
           if (subscription.status) {
             if (subscription.status.state === 'AtLatestKnown') {
@@ -286,7 +310,7 @@ export class OLMTasks {
         title: 'Approve installation',
         enabled: (ctx: any) => ctx.installPlanName,
         task: async (ctx: any, task: any) => {
-          await kube.approveOperatorInstallationPlan(ctx.installPlanName, flags.chenamespace)
+          await kube.approveOperatorInstallationPlan(ctx.installPlanName, ctx.operatorNamespace)
           task.title = `${task.title}...done.`
         },
       },
@@ -294,7 +318,7 @@ export class OLMTasks {
         title: 'Wait while newer operator installed',
         enabled: (ctx: any) => ctx.installPlanName,
         task: async (ctx: any, task: any) => {
-          await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, flags.chenamespace, 60)
+          await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, ctx.operatorNamespace, 60)
           ctx.highlightedMessages.push(`Operator is updated from ${ctx.currentVersion} to ${ctx.nextVersion} version`)
           task.title = `${task.title}...done.`
         },
@@ -305,6 +329,7 @@ export class OLMTasks {
 
   deleteTasks(flags: any): ReadonlyArray<Listr.ListrTask> {
     const kube = new KubeHelper(flags)
+    const che = new CheHelper(flags)
     return [
       {
         title: 'Check if OLM is pre-installed on the platform',
@@ -314,42 +339,64 @@ export class OLMTasks {
         },
       },
       {
-        title: `Delete(OLM) operator subscription ${SUBSCRIPTION_NAME}`,
-        enabled: ctx => ctx.isPreInstalledOLM,
-        task: async (_ctx: any, task: any) => {
-          await kube.deleteOperatorSubscription(SUBSCRIPTION_NAME, flags.chenamespace)
+        title: 'Check if operator is installed',
+        task: async (ctx: any, task: any) => {
+          const subscription = await che.findCheOperatorSubscription(flags.chenamespace)
+          if (subscription) {
+            ctx.subscriptionName = subscription.metadata.name
+            ctx.operatorNamespace = subscription.metadata.namespace
+            task.title = `${task.title}...Found ${ctx.subscriptionName}`
+          } else {
+            ctx.operatorNamespace = flags.chenamespace || DEFAULT_CHE_NAMESPACE
+            task.title = `${task.title}...Not Found`
+          }
+          // Also get operator group here, because if delete subscription and csv we'll lose the link to it
+          ctx.operatorGroup = await che.findCheOperatorOperatorGroup(ctx.operatorNamespace)
+        },
+      },
+      {
+        title: 'Delete(OLM) operator subscription',
+        enabled: ctx => ctx.isPreInstalledOLM && ctx.subscriptionName,
+        task: async (ctx: any, task: any) => {
+          await kube.deleteOperatorSubscription(ctx.subscriptionName, ctx.operatorNamespace)
           task.title = `${task.title}...OK`
         },
       },
       {
         title: 'Delete(OLM) CodeReady Workspaces cluster service versions',
         enabled: ctx => ctx.isPreInstalledOLM,
-        task: async (_ctx: any, task: any) => {
-          const csvs = await kube.getClusterServiceVersions(flags.chenamespace)
+        task: async (ctx: any, task: any) => {
+          const csvs = await kube.getClusterServiceVersions(ctx.operatorNamespace)
           const csvsToDelete = csvs.items.filter(csv => csv.metadata.name!.startsWith(CVS_PREFIX))
-          csvsToDelete.forEach(csv => kube.deleteClusterServiceVersion(flags.chenamespace, csv.metadata.name!))
+          for (const csv of csvsToDelete) {
+            await kube.deleteClusterServiceVersion(ctx.operatorNamespace, csv.metadata.name!)
+          }
           task.title = `${task.title}...OK`
         },
       },
       {
-        title: `Delete(OLM) operator group ${OPERATOR_GROUP_NAME}`,
-        enabled: ctx => ctx.isPreInstalledOLM,
-        task: async (_ctx: any, task: any) => {
-          await kube.deleteOperatorGroup(OPERATOR_GROUP_NAME, flags.chenamespace)
+        title: 'Delete(OLM) operator group',
+        // Do not delete global operator group if operator is in all namespaces mode
+        enabled: ctx => ctx.isPreInstalledOLM && ctx.operatorNamespace !== DEFAULT_OPENSHIFT_OPERATORS_NS_NAME,
+        task: async (ctx: any, task: any) => {
+          const opgr = ctx.operatorGroup
+          if (opgr && opgr.metadata && opgr.metadata.name && opgr.metadata.namespace) {
+            await kube.deleteOperatorGroup(opgr.metadata.name, opgr.metadata.namespace)
+          }
           task.title = `${task.title}...OK`
         },
       },
       {
-        title: `Delete(OLM) custom catalog source ${CUSTOM_CATALOG_SOURCE_NAME}`,
-        task: async (_ctx: any, task: any) => {
-          await kube.deleteCatalogSource(flags.chenamespace, CUSTOM_CATALOG_SOURCE_NAME)
+        title: TASK_TITLE_DELETE_CUSTOM_CATALOG_SOURCE,
+        task: async (ctx: any, task: any) => {
+          await kube.deleteCatalogSource(ctx.operatorNamespace, CUSTOM_CATALOG_SOURCE_NAME)
           task.title = `${task.title}...OK`
         },
       },
       {
-        title: `Delete(OLM) nigthly catalog source ${NIGHTLY_CATALOG_SOURCE_NAME}`,
-        task: async (_ctx: any, task: any) => {
-          await kube.deleteCatalogSource(flags.chenamespace, NIGHTLY_CATALOG_SOURCE_NAME)
+        title: TASK_TITLE_DELETE_NIGHTLY_CATALOG_SOURCE,
+        task: async (ctx: any, task: any) => {
+          await kube.deleteCatalogSource(ctx.operatorNamespace, NEXT_CATALOG_SOURCE_NAME)
           task.title = `${task.title}...OK`
         },
       },
@@ -357,14 +404,14 @@ export class OLMTasks {
         title: `Delete role ${this.prometheusRoleName}`,
         task: async (_ctx: any, task: any) => {
           await kube.deleteRole(this.prometheusRoleName, flags.chenamespace)
-          task.title = await `${task.title}...OK`
+          task.title = `${task.title}...OK`
         },
       },
       {
         title: `Delete role binding ${this.prometheusRoleName}`,
         task: async (_ctx: any, task: any) => {
           await kube.deleteRoleBinding(this.prometheusRoleName, flags.chenamespace)
-          task.title = await `${task.title}...OK`
+          task.title = `${task.title}...OK`
         },
       },
     ]
@@ -377,7 +424,7 @@ export class OLMTasks {
         if (!await kube.isPreInstalledOLM()) {
           cli.warn('Looks like your platform hasn\'t got embedded OLM, so you should install it manually. For quick start you can use:')
           cli.url('install.sh', 'https://raw.githubusercontent.com/operator-framework/operator-lifecycle-manager/master/deploy/upstream/quickstart/install.sh')
-          command.error('OLM is required for installation CodeReady Workspaces with installer flag \'olm\'')
+          command.error('OLM is required for installation of CodeReady Workspaces with installer flag \'olm\'')
         }
         task.title = `${task.title}...done.`
       },
@@ -408,7 +455,7 @@ export class OLMTasks {
       apiVersion: 'operators.coreos.com/v1alpha1',
       kind: 'CatalogSource',
       metadata: {
-        name: NIGHTLY_CATALOG_SOURCE_NAME,
+        name: NEXT_CATALOG_SOURCE_NAME,
         namespace,
       },
       spec: {
@@ -423,23 +470,18 @@ export class OLMTasks {
     }
   }
 
-  private async getCRFromCSV(kube: KubeHelper, cheNamespace: string): Promise<any> {
-    const subscription: Subscription = await kube.getOperatorSubscription(SUBSCRIPTION_NAME, cheNamespace)
-    const currentCSV = subscription.status!.currentCSV
-    const csv = await kube.getCSV(currentCSV, cheNamespace)
+  private async getCRFromCSV(kube: KubeHelper, namespace: string, subscriptionName: string): Promise<any> {
+    const subscription = await kube.getOperatorSubscription(subscriptionName, namespace)
+    if (!subscription) {
+      throw new Error(`Subscription '${subscriptionName}' not found in namespace '${namespace}'`)
+    }
+    const installedCSV = subscription.status!.installedCSV!
+    const csv = await kube.getCSV(installedCSV, namespace)
     if (csv && csv.metadata.annotations) {
       const CRRaw = csv.metadata.annotations!['alm-examples']
-      return (yaml.load(CRRaw) as Array<any>)[0]
+      return (yaml.load(CRRaw) as Array<any>).find(cr => cr.kind === 'CheCluster')
     } else {
-      throw new Error(`Unable to retrieve Che cluster CR definition from CSV: ${currentCSV}`)
+      throw new Error(`Unable to retrieve Che cluster CR definition from CSV: ${installedCSV}`)
     }
   }
-
-  private getOlmNamespaceLabels(flags: any): any {
-    // The label values must be strings
-    if (flags['cluster-monitoring'] && flags.platform === 'openshift') {
-      return { 'openshift.io/cluster-monitoring': 'true' }
-    }
-    return {}
-  }
 }
